User-centric changelog
======================

**1.0.3 --- 2015-02-22**

  * Fixed the ``MANIFEST.in`` so the package is finally ``easy_install``-able
  * Added the release check script stub
  * Updated install docs

**1.0.2 --- 2015-02-21**

  * Documentation and setup.py fixes

**1.0.1 --- 2015-02-19**
  
  * Real debut on PyPi
  * Fixed some minor issues with setup.py and docs

**1.0.0 --- 2015-02-19**
  
  Beginning of the changelog.

  * Debut on PyPi
